#runs carbon cycle model with linear feedbacks. Option to include anthropogenic fluxes or not.

#Set anthro to TRUE to include anthropogenic fluxes; set anthro to FALSE to exclude anthropogenic fluxes
#anthro=FALSE
anthro=TRUE

#number of time steps
tf=200

#Set the initial value of each pool (initialize pools)
Plant0=560
Soil0=1500
Atmosphere0=750
Ocean0=38000

#Set up vectors (using the rep function) of length tf that are filled with 0s for each pool. The values at each time step will be stored in these vectors.
Plant=rep(0,tf)
Soil=rep(0,tf)
Atmosphere=rep(0,tf)
Ocean=rep(0,tf)

#Set the first value in each vector to the initial value of the pools
Plant[1]=Plant0
Soil[1]=Soil0
Atmosphere[1]=Atmosphere0
Ocean[1]=Ocean0

#Initialize Fluxes
Rp=60 	#Plant respiration
PS=120 	#Photosynthesis
Rd=60 	#Soil respiration
R=0.8 	#Rivers
O2A=90 	#Ocean to atmosphere
A2O=92 	#Atmosphere to ocean
OB=0.1 	#Ocean burial

if (anthro==TRUE){
	FF=6#Fossil fuels
	VD=0.9#Vegetation destruction
}
if (anthro==FALSE){
	FF=0
	VD=0
}

#TO SIMPLIFY: only processes included are respiration and photosynthesis
#Comment these out to make it more complicated
#OB=0
#O2A=0
#A2O=0
#R=0

#Set k values for linear donor control model: K=flux/pool
k.PS=PS/Atmosphere[1]
k.Rp=Rp/Plant[1]
k.Rd=Rd/Soil[1]
k.R=R/Soil[1]
k.O2A=O2A/Ocean[1]
k.A2O=A2O/Atmosphere[1]
k.OB=OB/Ocean[1]
#Anthropogenic
k.VD=VD/Plant[1]
#k.FF=FF/Soil[1] # commented this out because I don't think it really depends on the other pools in the model...


###########################
#Running the model is below
#First, write if statements to determine if the model option is constant flux or linear donor contorl
#Then, create a loop to run the model tf time steps
#At every time step, store the value for each pool in the pool vector

#run with linear feedbacks
	
#For every time step from 1 to the final time step, do the things inside the squiggle brackets
for (t in 1:tf){
	
	#pool at next time step = pool at current time step + k*Pool
	Plant[t+1]=Plant[t]+Atmosphere[t]*k.PS-Plant[t]*k.Rp-k.VD*Plant[t]
	Soil[t+1]=Soil[t]-Soil[t]*k.Rd+Ocean[t]*k.OB-Soil[t]*k.R-FF
	Ocean[t+1]=Ocean[t]+Atmosphere[t]*k.A2O-Ocean[t]*k.O2A-Ocean[t]*k.OB+Soil[t]*k.R
	Atmosphere[t+1]=Atmosphere[t]-Atmosphere[t]*k.A2O+Ocean[t]*k.O2A-Atmosphere[t]*k.PS+Plant[t]*k.Rp+Soil[t]*k.Rd+FF+k.VD*Plant[t]
}#End for loop

PlantOld=Plant
SoilOld=Soil
AtmosphereOld=Atmosphere
OceanOld=Ocean

par(mfrow=c(4,2))
plot(Plant)
plot(PlantOld)
plot(Soil)
plot(SoilOld)

#plot
par(mfrow=c(2,2))#Set the screen to show 2x2 plots
plot(Plant,col="green",xlab="time (years)")
plot(Soil,col="brown")
plot(Ocean,col="blue")
plot(Atmosphere,col="red")

#You can also plot the total C in all the pools.
#par(mfrow=c(1,1))
#plot(Plant+Soil+Ocean+Atmosphere,col="black")
